@@ -11,7 +11,7 @@ testthat::test_that("Forecast", {
   
   tol <- 0.05
   set.seed(1234)
-  est.forecast <- MSGARCH::Forecast(object = spec,par = par,data = SMI,n.ahead = 2)$vol
+  est.forecast <- predict(object = spec, par = par, newdata = SMI,nahead = 2)$vol
   exp.forecast <- c(1.0304257211510406, 1.0340222685323162)
   
   testthat::expect_true(max(abs(est.forecast - exp.forecast)) < tol)
@@ -21,7 +21,7 @@ testthat::test_that("Forecast", {
 testthat::test_that("Conditional Vol", {
   
   tol <- 0.05
-  est.Vol <- MSGARCH::Volatility(object = spec, par = par, data = SMI)[2000]
+  est.Vol <- Volatility(object = spec, par = par, data = SMI)[2000]
   exp.Vol <- c(2.1321725800180471)
   
   testthat::expect_true(max(abs(est.Vol - exp.Vol)) < tol)
